@@ -1,4 +1,5 @@
 from abc import ABC, abstractmethod
+from typing import Dict
 
 from pandas import DataFrame
 from pydantic.main import BaseModel
@@ -17,3 +18,7 @@ class BaseStep(BaseModel, ABC):
         self, df: DataFrame, domain_retriever: DomainRetriever, pipeline_executor: PipelineExecutor
     ) -> DataFrame:
         ...
+
+    # None values are excluded, to avoid triggering validation error in Tucana
+    def dict(self, *, exclude_none: bool = True, **kwargs) -> Dict:
+        return super().dict(exclude_none=True, **kwargs)
